==> vtk6-6.3.0-2-armv7h.pkg.tar.xz: vtk/vtkImageLogic.java <==
// java wrapper for vtkImageLogic object
//

package vtk;
import vtk.*;

public class vtkImageLogic extends vtkThreadedImageAlgorithm
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetOperation_2(int id0);
  public void SetOperation(int id0)
    { SetOperation_2(id0); }

  private native int GetOperation_3();
  public int GetOperation()
    { return GetOperation_3(); }

  private native void SetOperationToAnd_4();
  public void SetOperationToAnd()
    { SetOperationToAnd_4(); }

  private native void SetOperationToOr_5();
  public void SetOperationToOr()
    { SetOperationToOr_5(); }

  private native void SetOperationToXor_6();
  public void SetOperationToXor()
    { SetOperationToXor_6(); }

  private native void SetOperationToNand_7();
  public void SetOperationToNand()
    { SetOperationToNand_7(); }

  private native void SetOperationToNor_8();
  public void SetOperationToNor()
    { SetOperationToNor_8(); }

  private native void SetOperationToNot_9();
  public void SetOperationToNot()
    { SetOperationToNot_9(); }

  private native void SetOutputTrueValue_10(double id0);
  public void SetOutputTrueValue(double id0)
    { SetOutputTrueValue_10(id0); }

  private native double GetOutputTrueValue_11();
  public double GetOutputTrueValue()
    { return GetOutputTrueValue_11(); }

  private native void SetInput1Data_12(vtkDataObject id0);
  public void SetInput1Data(vtkDataObject id0)
    { SetInput1Data_12(id0); }

  private native void SetInput2Data_13(vtkDataObject id0);
  public void SetInput2Data(vtkDataObject id0)
    { SetInput2Data_13(id0); }

  public vtkImageLogic() { super(); }

  public vtkImageLogic(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-14-armv7h.pkg.tar.xz: vtk/vtkImageLogic.java <==
// java wrapper for vtkImageLogic object
//

package vtk;
import vtk.*;

public class vtkImageLogic extends vtkThreadedImageAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetOperation_2(int id0);
  public void SetOperation(int id0)
    { SetOperation_2(id0); }

  private native int GetOperation_3();
  public int GetOperation()
    { return GetOperation_3(); }

  private native void SetOperationToAnd_4();
  public void SetOperationToAnd()
    { SetOperationToAnd_4(); }

  private native void SetOperationToOr_5();
  public void SetOperationToOr()
    { SetOperationToOr_5(); }

  private native void SetOperationToXor_6();
  public void SetOperationToXor()
    { SetOperationToXor_6(); }

  private native void SetOperationToNand_7();
  public void SetOperationToNand()
    { SetOperationToNand_7(); }

  private native void SetOperationToNor_8();
  public void SetOperationToNor()
    { SetOperationToNor_8(); }

  private native void SetOperationToNot_9();
  public void SetOperationToNot()
    { SetOperationToNot_9(); }

  private native void SetOutputTrueValue_10(double id0);
  public void SetOutputTrueValue(double id0)
    { SetOutputTrueValue_10(id0); }

  private native double GetOutputTrueValue_11();
  public double GetOutputTrueValue()
    { return GetOutputTrueValue_11(); }

  private native void SetInput1Data_12(vtkDataObject id0);
  public void SetInput1Data(vtkDataObject id0)
    { SetInput1Data_12(id0); }

  private native void SetInput2Data_13(vtkDataObject id0);
  public void SetInput2Data(vtkDataObject id0)
    { SetInput2Data_13(id0); }

  public vtkImageLogic() { super(); }

  public vtkImageLogic(long id) { super(id); }
  public native long   VTKInit();

}
